@@ -28,7 +28,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.58';
+our $VERSION = '0.63';
 
 
 # Preloaded methods go here.
@@ -275,10 +275,9 @@ Script::Toolbox - Framework for the daily business scripts
   # CheckBox Menus
   #---------------
   my $x = CheckBox('Head2',',AAA,BBB,ccc','ccc|AAA'); # BBB is off
-  my $x = CheckBox('Head4',',AAA,BBB,ccc','ccc', 1 ); # radio-button, ccc is on
   my $m = Script::Toolbox::Util::Menus->new();
-  my $x = CheckBox('Head7',',AAA,BBB,ccc',undef, 0,$m); # temp. in container $m
-  my $x = CheckBox('HeadC',',AAA,BBB,ccc','ccc', 1,$m,'testmenu');
+  my $x = CheckBox('Head7',',AAA,BBB,ccc',undef, $m); # temp. in container $m
+  my $x = CheckBox('HeadC',',AAA,BBB,ccc','ccc', $m,'testmenu');
                                               #  testmenu perm. in container $m
 
 
@@ -350,26 +349,31 @@ returned. The callback function may return one scalar value.
 =item File( '> path/to/file', 'overwrite the old content' )
 
 Write the string to the file. Overwrite the old content of the file.
+Return undef in case of an error otherwise 1;
 
 =item File( 'path/to/file', 'append this to the file' )
 
 Append the string to the file.
+Return undef in case of an error otherwise 1;
 
 
 =item File( 'path/to/file', $arrRef )
 
 Append each array element to the end of the file as is (no automatic newline).
+Return undef in case of an error otherwise 1;
 
 
 =item File( 'path/to/file', $arrRef, $recSep )
 
 Concatenate each array element with the record separator and append it to the file. 
+Return undef in case of an error otherwise 1;
 
 
 =item File( 'path/to/file', $hashRef, $recSep, $fieldSep )
 
 Append records like  KEY$fieldSepVALUE$recSep to the file. Default record separator is 
 the empty string. Default field separator is ':';
+Return undef in case of an error otherwise 1;
 
 
 =item $arrRef = FileC('/path/to/file')
@@ -763,6 +767,18 @@ This method provides setting of the default fields of options.
 <values> is a hash like {<label> => <value>}. Only updates on existing
 labels are allowed.
 
+=item setReadOnlys(<name>,<readOnly>)
+
+This method provides setting of the readOnly fields of options.
+<readOnly> is a hash like {<label> => <readOnly>}. Only updates on existing
+labels are allowed.
+
+=item setJumps(<name>,<jump>)
+
+This method provides setting of the jump fields of options.
+<jump> is a hash like {<label> => <jump>}. Only updates on existing
+labels are allowed.
+
 =back
 
 
@@ -787,7 +803,7 @@ If a default is defined, like this:
 and the input is a single space character, then the 'default' will be
 assigned to 'value'.
 
-=item CheckBox(<head>,<opts>[,<preSel>[,<radio>[,<cont>[,<menName>]]]])
+=item CheckBox(<head>,<opts>[,<preSel>[,<cont>[,<menName>]]]])
 
 Display the options <opts> as menu. Each of them has an autogenerated 
 value field with possible values of '' (means: OFF) or 'x' (means: ON).
@@ -797,6 +813,17 @@ Selecting an option, toggles the value of the value field.
 
 CheckBox() returns a hash like {'on'=>[a,b],'off'=>[c,d,e]}.
 
+=item RadioButton(<head>,<opts>[<preSel>[,<cont>[,<menName>]]]])
+
+Display the options <opts> as menu. Each of them has an autogenerated 
+value field with possible values of '' (means: OFF) or 'x' (means: ON).
+Only one option at the same time can be ON.
+<preSel> is a regular expression matching one of the labels.
+The option with this label gets in ON state. All other options are switched OFF.
+Selecting an option switch it ON and all other OFF.
+
+RadioButton() returns a hash like {'on'=>[a,b],'off'=>[c,d,e]}.
+
 =over 4
 
 =item head
@@ -813,10 +840,6 @@ means: ',a,b,c' with first character of the string as separator character.
 A regular expression. Each option where label matching this regex gets
 in state ON.
 
-=item radio
-
-If true, radio-button behavior is active. Only one option can be in state ON.
-
 =item cont
 
 Menus container to store the check box in. Usualy used together with option
